import { r as registerInstance, c as createEvent, h, g as getElement } from './index-cdf8e526.js';
import { m as modifiersToClass, r as regexValidators } from './utils-f909044c.js';

const textfieldCss = ".ibk-textfield{width:100%;box-sizing:border-box}.ibk-textfield *{box-sizing:border-box}.ibk-textfield__label{font-family:var(--fontGeometria);font-size:14px;padding-bottom:5px;display:block;font-weight:500;color:var(--gray1)}.ibk-textfield__subtitle{font-family:var(--fontMontserrat);color:var(--grayText);font-size:14px;font-weight:500;padding-bottom:7px;display:block}.ibk-textfield__input{display:flex;align-items:center;width:100%;border:1px solid var(--gray4);border-radius:4px;height:48px;transition:var(--fast);background-color:white}@media screen and (max-width: 360px){.ibk-textfield__input{height:44px}}.ibk-textfield__input:hover{border-color:var(--gray3)}.ibk-textfield__value{width:100%;appearance:none;-webkit-appearance:none;-moz-appearance:none;border:none;outline:none;display:block;height:100%;padding:0 15px;font-family:var(--fontGeometria);font-size:16px;font-weight:500;color:var(--grayText);background-color:transparent}.ibk-textfield__value::placeholder{color:var(--gray2);font-weight:400}.ibk-textfield__value::-ms-reveal,.ibk-textfield__value::-ms-clear{display:none}.ibk-textfield__value::-webkit-outer-spin-button,.ibk-textfield__value::-webkit-inner-spin-button{-webkit-appearance:none;margin:0}.ibk-textfield--focus .ibk-textfield__input{border-color:var(--primaryGreen1);box-shadow:inset 0 0 0 0.5px var(--primaryGreen1)}.ibk-textfield__trailing-icon{padding-right:15px;color:var(--primaryGreen1);cursor:text}.ibk-textfield__leading-icon{padding-left:15px;color:var(--primaryGreen1);cursor:text}.ibk-textfield--erasable .ibk-textfield__trailing-icon{color:var(--gray1)}.ibk-textfield--password .ibk-textfield__trailing-icon,.ibk-textfield--erasable .ibk-textfield__trailing-icon{cursor:pointer}.ibk-textfield--password .ibk-textfield__trailing-icon:active,.ibk-textfield--erasable .ibk-textfield__trailing-icon:active{transform:translateY(1px)}.ibk-textfield--error .ibk-textfield__input{border-color:var(--extendedWatermelon1)}.ibk-textfield--error.ibk-textfield--focus .ibk-textfield__input{box-shadow:inset 0 0 0 0.5px var(--extendedWatermelon1)}.ibk-textfield--error .ibk-textfield__trailing-icon,.ibk-textfield--error .ibk-textfield__leading-icon{color:var(--extendedWatermelon1)}.ibk-textfield__error-message{font-family:var(--fontMontserrat);font-size:12px;color:var(--extendedWatermelon1);font-weight:500;margin-top:7px;display:block;min-height:15px}.ibk-textfield--disabled{cursor:default;pointer-events:none}.ibk-textfield--disabled .ibk-textfield__input{background-color:var(--gray5)}";

const IbkTextfield = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.onchange = createEvent(this, "onchange", 7);
    this.onfocus = createEvent(this, "onfocus", 7);
    /** Tipo de contenido que se ingresará en el campo de texto */
    this.type = 'text';
    /** Cuando se encuentra dentro de un "ibk-form" al hacer submit si el campo de texto se encuentra vacío, mostrará un mensaje de error */
    this.required = false;
    /** Personaliza el mensaje de campo requerido */
    this.requiredMessage = 'Este campo es requerido';
    /** Se mostrará un mensaje de error */
    this.error = false;
    /** Personaliza el mensaje de error */
    this.errorMessage = 'Por favor, ingrese este campo correctamente';
    /** Contenido del campo de texto */
    this.value = '';
    /** Define si el textfield no contará con manejo de errores. Se omitirá el espacio generado para el mensaje de error */
    this.noHandlingError = false;
    /** Muestra un icono a la izquierda con una X que sirve para borrar el contenido del campo de texto */
    this._erasable = false;
    /** Estado activo o inactivo del campo de texto */
    this._focus = false;
    /** Estado que determina si la contraseña está visible o no */
    this._showingPwd = false;
    /** Configura el tipo de campo de texto en base a la configuración del componente */
    this.setInputType = () => {
      let type = '';
      if (this.type == 'password' && !this._showingPwd) {
        type = 'password';
      }
      else if (this.type == 'date') {
        type = this.type;
      }
      else {
        type = 'text';
      }
      return type;
    };
    /** Define el máximo de caracteres en base a la configuración del componente */
    this.setMaxLength = () => {
      let length = 0;
      if (this.type == 'expiration') {
        length = 5;
      }
      else if (this.type == 'cvv') {
        length = 4;
      }
      else if (this.type == 'dni') {
        length = 8;
      }
      else if (this.type == 'document') {
        length = 16;
      }
      else if (this.type == 'phone') {
        length = 9;
      }
      return length;
    };
    /** Configura el icono del lado izquierdo en base a la configuración del componente */
    this.setTrailingIcon = () => {
      let icon = '';
      if (this.type == 'password') {
        icon = this._showingPwd ? 'icon-m-eye-off' : 'icon-m-eye-on';
      }
      else if (this._erasable) {
        icon = 'icon-m-status-error';
      }
      else if (this.trailingIcon) {
        icon = this.trailingIcon;
      }
      return icon;
    };
    /** Determina la función a realizar en base al icono actual */
    this.trailingIconFunction = () => {
      if (this.type == 'password') {
        this._showingPwd = !this._showingPwd;
      }
      else if (this._erasable) {
        const input = this.host.querySelector('.ibk-textfield__value');
        input.value = '';
        this._erasable = false;
      }
    };
    /** Determina el mensaje de error a mostrar en base a la configuración del componente */
    this.setErrorMessage = () => {
      let msg = '';
      if (this.required && this.error && this.value.length == 0) {
        msg = this.requiredMessage;
      }
      else if (this.error) {
        msg = this.errorMessage;
      }
      return msg;
    };
    /** Escucha y emite el evento editing cuando cambia el contenido */
    this.onInputChange = (e) => {
      const t = e.target;
      this.value = t.value;
      if (this.value != '') {
        this.host.removeAttribute('error');
        this._erasable = true;
      }
      else {
        this._erasable = false;
      }
      if (this.type == 'expiration' && t.value.length == 2 && this._keyCode != 8) {
        this.value += '/';
      }
      if (this._grouper != null) {
        this._grouper.removeAttribute('error');
      }
      this.onchange.emit(t.value);
    };
  }
  componentWillLoad() {
    this._grouper = this.host.closest('ibk-form-group');
  }
  onInputFocusIn() {
    this._focus = true;
    this.onfocus.emit('in');
  }
  onInputFocusOut() {
    this._focus = false;
    this.onfocus.emit('out');
    /** Validación para fecha de expiración */
    if (this.type == 'expiration' && this.value.length == 5) {
      const exp = this.value.split('/');
      const currentYear = new Date().getFullYear().toString();
      const formatYear = currentYear.slice(2);
      if (parseInt(exp[0]) > 12 || parseInt(exp[1]) < parseInt(formatYear)) {
        this.host.setAttribute('error', '');
      }
    }
  }
  /** Configura la clase del componente basado en estados y modificadores */
  containerClass() {
    return modifiersToClass('ibk-textfield', [
      this.type,
      { focus: this._focus },
      { erasable: this._erasable },
      { error: this.error },
      { disabled: this.disabled }
    ]);
  }
  onKeyDown(e) {
    this._keyCode = e.keyCode;
    if (['expiration', 'cvv', 'dni'].includes(this.type) && !regexValidators.number.test(e.key) && (this._keyCode != 8 && this._keyCode != 9)) {
      e.preventDefault();
    }
    else if (this.type == 'number' && !regexValidators.numberFormat.test(e.key) && (this._keyCode != 8 && this._keyCode != 9)) {
      e.preventDefault();
    }
  }
  render() {
    var _a;
    return (h("div", { class: this.containerClass(), style: { width: this.width + 'px' } }, this.label && h("span", { class: "ibk-textfield__label" }, this.label), this.subtitle && h("span", { class: "ibk-textfield__subtitle" }, this.subtitle), h("label", { class: "ibk-textfield__input" }, this.leadingIcon && h("i", { class: 'ibk-textfield__leading-icon ' + this.leadingIcon }), h("input", { class: "ibk-textfield__value", type: this.setInputType(), placeholder: this.placeholder, maxLength: (_a = this.maxLength) !== null && _a !== void 0 ? _a : (this.setMaxLength() > 0 ? this.setMaxLength() : null), value: this.value, onInput: this.onInputChange }), this.setTrailingIcon() != '' && h("i", { class: 'ibk-textfield__trailing-icon ' + this.setTrailingIcon(), onClick: this.trailingIconFunction })), !this.noHandlingError && h("span", { class: "ibk-textfield__error-message" }, this.setErrorMessage())));
  }
  get host() { return getElement(this); }
};
IbkTextfield.style = textfieldCss;

export { IbkTextfield as ibk_textfield };
